==> ktp-accounts-kcm-0.5.80.tar.bz2: ktp-accounts-kcm-0.5.80/plugins/gabble/ktpaccountskcm_plugin_gabble.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Gabble connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Gabble menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Gabble.
Comment[ca@valencia]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Gabble.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Gabble.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Gabble.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Gabble-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Gabble.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Gabble.
Comment[et]=Gabble'i ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[fi]=Gabble-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur de configuration de comptes personnalisés pour les comptes utilisant le gestionnaire de connexion Gabble.
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Gabble.
Comment[hu]=Egyedi beállítófelület a Gabble kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Gabble.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Gabble.
Comment[kk]=Gabble байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី​ផ្ទាល់ខ្លួន​សម្រាប់​គណនី​ដែល​បាន​ប្រើ​កម្មវិធី​គ្រប់គ្រង​ការ​តភ្ជាប់ Gabble ។
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Gabble ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Gabble tilkoblingsbehandler.
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Gabble verbindingenbeheerder gebruiken.
Comment[pl]=Własny interfejsu użytkownika konfiguracji kont dla kont wykorzystujących menadżera połączeń Gabble.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Gabble.
Comment[pt_BR]=Interface de configuração de contas personalizadas usando o gerenciador de conexões Gabble.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Gabble.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Gabble.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Gabble.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Gabble.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Габл.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Габл.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Gabble.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Gabble.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Gabble.
Comment[tr]=Gabble bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштування облікового запису за допомогою керування з’єднаннями Gabble.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Gabble.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Gabble connection manager.xx
Comment[zh_CN]=通过 Gabble 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Gabble 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Gabble Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Gabble
Name[ca]=Interfície d'usuari de configuració de compte de Gabble
Name[ca@valencia]=Interfície d'usuari de configuració de compte de Gabble
Name[cs]=Uživatelské rozhraní nastavení účtu Gabble
Name[da]=Brugerflade til Gabble kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Gabble-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη με Gabble
Name[es]=Interfaz de configuración de cuentas Gabble
Name[et]=Gabble'i konto seadistamise kasutajaliides
Name[fi]=Gabble-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur de configuration de comptes Gabble
Name[gl]=Interface de usuario para a configuración de contas de Gabble
Name[hu]=Gabble azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Gabble
Name[it]=Interfaccia utente di configurazione account Gabble
Name[kk]=Gabble тіркелгі пайдаланушы интерфейсін баптау
Name[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការកំណត់​រចនាសម្ព័ន្ធ​គណនី​​​របស់ Gabble
Name[lt]=Gabble paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Gabble-konto
Name[nl]=Gebruikersinterface voor Gabble accountconfiguratie
Name[pl]=Interfejs użytkownika konfiguracji konta Gabble
Name[pt]=Interface de Configuração de Contas do Gabble
Name[pt_BR]=Interface de configuração de contas do Gabble
Name[ro]=Interfață de configurare a conturilor Gabble
Name[ru]=Интерфейс для настройки учётной записи Gabble
Name[sk]=Používateľské rozhranie konfigurácie účtu Gabble
Name[sl]=Uporabniški vmesnik za nastavitev računov Gabble
Name[sr]=Корисничко сучеље за подешавање налога под Габлом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Габлом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod Gabbleom
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod Gabbleom
Name[sv]=Användargränssnitt för inställning av Gabble-konton
Name[tr]=Gabble Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштування Gabble
Name[wa]=Eterface uzeu d' apontiaedje des contes Gabble
Name[x-test]=xxGabble Account Configuration User Interfacexx
Name[zh_CN]=Gabble 账户用户配置界面
Name[zh_TW]=Gabble 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_gabble
X-KDE-PluginInfo-Author=George Goldberg
X-KDE-PluginInfo-Email=george.goldberg@collabora.co.uk
X-KDE-PluginInfo-Name=gabble
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-accounts-kcm-0.6.3.tar.bz2: ktp-accounts-kcm-0.6.3/plugins/gabble/ktpaccountskcm_plugin_gabble.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the Gabble connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći Gabble menadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Gabble.
Comment[ca@valencia]=Interfície d'usuari de configuració de compte personalitzat per comptes que utilitzen el gestor de connexions Gabble.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení Gabble.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen Gabble.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Gabble-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων Gabble.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones Gabble.
Comment[et]=Gabble'i ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[fi]=Gabble-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « Gabble ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Gabble.
Comment[hu]=Egyedi beállítófelület a Gabble kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Gabble.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Gabble.
Comment[kk]=Gabble байланыс менеджерін қолданатын тіркелгі пайдаланушы интерфейс параметрлерін ыңғайлау.
Comment[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការ​កំណត់​រចនាសម្ព័ន្ធ​គណនី​ផ្ទាល់ខ្លួន​សម្រាប់​គណនី​ដែល​បាន​ប្រើ​កម្មវិធី​គ្រប់គ្រង​ការ​តភ្ជាប់ Gabble ។
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant Gabble ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av Gabble tilkoblingsbehandler.
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Gabble verbindingenbeheerder gebruiken.
Comment[pl]=Własny interfejsu użytkownika konfiguracji kont dla kont wykorzystujących menadżera połączeń Gabble.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Gabble.
Comment[pt_BR]=Interface de configuração de contas personalizadas usando o gerenciador de conexões Gabble.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Gabble.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью менеджера соединений Gabble.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Gabble.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Gabble.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Габл.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Габл.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Gabble.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze Gabble.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Gabble.
Comment[tr]=Gabble bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштування облікового запису за допомогою керування з’єднаннями Gabble.
Comment[wa]=Eterface uzeu po-z apontyî a vosse môde les contes tot s' siervant do manaedjeu d' raloyaedje Gabble.
Comment[x-test]=xxCustom account configuration user interface for accounts using the Gabble connection manager.xx
Comment[zh_CN]=通过 Gabble 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 Gabble 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Gabble Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Gabble
Name[ca]=Interfície d'usuari de configuració de compte de Gabble
Name[ca@valencia]=Interfície d'usuari de configuració de compte de Gabble
Name[cs]=Uživatelské rozhraní nastavení účtu Gabble
Name[da]=Brugerflade til Gabble kontokonfiguration
Name[de]=Benutzeroberfläche zur Einrichtung von Gabble-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη με Gabble
Name[es]=Interfaz de configuración de cuentas Gabble
Name[et]=Gabble'i konto seadistamise kasutajaliides
Name[fi]=Gabble-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « Gabble ».
Name[gl]=Interface de usuario para a configuración de contas de Gabble
Name[hu]=Gabble azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Gabble
Name[it]=Interfaccia utente di configurazione account Gabble
Name[kk]=Gabble тіркелгі пайдаланушы интерфейсін баптау
Name[km]=ចំណុច​ប្រទាក់​អ្នក​ប្រើ​ការកំណត់​រចនាសម្ព័ន្ធ​គណនី​​​របស់ Gabble
Name[lt]=Gabble paskyros konfigūravimo naudotojo sąsają
Name[nb]=Brukerflate for å sette opp Gabble-konto
Name[nl]=Gebruikersinterface voor Gabble accountconfiguratie
Name[pl]=Interfejs użytkownika konfiguracji konta Gabble
Name[pt]=Interface de Configuração de Contas do Gabble
Name[pt_BR]=Interface de configuração de contas do Gabble
Name[ro]=Interfață de configurare a conturilor Gabble
Name[ru]=Интерфейс для настройки учётной записи Gabble
Name[sk]=Používateľské rozhranie konfigurácie účtu Gabble
Name[sl]=Uporabniški vmesnik za nastavitev računov Gabble
Name[sr]=Корисничко сучеље за подешавање налога под Габлом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Габлом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod Gabbleom
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod Gabbleom
Name[sv]=Användargränssnitt för inställning av Gabble-konton
Name[tr]=Gabble Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштування Gabble
Name[wa]=Eterface uzeu d' apontiaedje des contes Gabble
Name[x-test]=xxGabble Account Configuration User Interfacexx
Name[zh_CN]=Gabble 账户用户配置界面
Name[zh_TW]=Gabble 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_gabble
X-KDE-PluginInfo-Author=George Goldberg
X-KDE-PluginInfo-Email=george.goldberg@collabora.co.uk
X-KDE-PluginInfo-Name=gabble
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=true
